@@ -1433,11 +1433,12 @@ class Client(commandServer, encrypt, Desktop):
 
             pathConfig = os.path.join(userHome,
                                       self.pathConfig)
+            
             try:
-                if iniParser(configFileName).setVar(
+                if iniParser(pathConfig).setVar(
                         'rsync', {'exitcode': rsync.getExitCode()}):
-                    os.chmod(configFileName, 0o600)
-                    os.chown(configFileName, uid, gid)
+                    os.chmod(pathConfig, 0o600)
+                    os.chown(pathConfig, uid, gid)
             except Exception:
                 pass
             if ps.exitstatus != 0:
