@@ -296,7 +296,8 @@ class ClClientSyncLoginAction(Action):
         {'name': 'newsync:domain_sync2',
          'method': 'Client.setSyncStatus(ur_home_path,ur_uid,ur_gid,"process")',
          'condition': lambda Get: Get('cl_client_sync') == 'on',
-         }, ] + old_sync + new_sync + [
+        #  }, ] + old_sync + new_sync + [
+         }, ] + old_sync + [
         # распаковать ссылки
         {'name': 'unpack_links',
          'method': 'Client.unpackLinks(ur_home_path)',
