@@ -664,7 +664,7 @@ class SyncHelper():
         cpRemote.read_string(iniEnvRemoteData)
 
         xSessionCur = cpCur.get('main', 'xsession', fallback=None)
-        xSessionThis = cpThis.get('main', 'xsession', fallback=None)
+        xSessionThis = cpRemote.get('main', 'xsession', fallback=None)
         if curStatusSync == "success_logout" and \
                         xSessionCur == xSessionThis:
             thisTimeObj = self.getSyncDate(osLinuxShort, ps)
@@ -749,6 +749,11 @@ class VariableClClientSyncReplicationSet(SyncHelper, ReadonlyVariable):
         remotehost = self.Get(self.host_varname)
         ps =  ProfileSyncer(remotehost, 2009, user, pwd)
 
+        #there was a typo before - profilePath was missing
+        profilePath = self.Select('cl_client_user_mount_path',
+                                  where='cl_client_user_mount_name',
+                                  eq=self.profile_type, limit=1)
+
         if ps.check():
             return "on" if self.checkNeedSyncNew(
                 self.Get('ur_home_path'), profilePath,
